@@ -1,6 +1,6 @@
 use common::sense;
 
-our $VERSION = '1.0';
+our $VERSION = '1.002';
 
 # ABSTRACT: Work with a deck of playing cards in the fashion engineered by Duane O'Brien of I.B.M. developerWorks.
 
@@ -232,7 +232,7 @@ This method provides a simulation of a fair dice roll.  The roll method takes a
             
         my $nick1 = $obj->random_nick(('nd', 'jp', 'smoke', 'gehenna')));
 
-This method is supplied with an array of strings containing nicks (or handles / aliases / moniker) to be used as a pool from which to draw a random value.  This value is a nick (or handle / alias).
+This method is supplied with an array of strings containing nicks (or handles / aliases / moniker) to be used as a pool from which to draw a random value.  This value is a nick (or handle / alias / moniker).
 
 =cut
 
@@ -294,7 +294,7 @@ This method is used to build a deck of playing cards.  The build_deck method ret
         Parameters : 
             Let d1 be a reference to a deck of playing cards (see method titled build_deck),
         Results :
-            Let d1 shuffled,
+            Let r be a reference to d1 once shuffled,
             
         my $r = $obj->shuffle_deck($d1);
 
@@ -368,7 +368,7 @@ This method returns a description of the odds as a string.  The calculate odds m
             
         my $r = $obj->build_lc_letter_array;
 
-The build_lc_letter_array returns an array of lower case letters [a - z].
+The build_lc_letter_array method returns an array of lower case letters [a - z].
 
 =cut
 
@@ -380,7 +380,7 @@ The build_lc_letter_array returns an array of lower case letters [a - z].
             
         my $r = $obj->build_uc_letter_array;
 
-The build_uc_letter_array returns an array of upper case letters [A - Z].
+The build_uc_letter_array method returns an array of upper case letters [A - Z].
 
 =cut
 
